@@ -1,9 +1,9 @@
-from aiod.authentication import invalidate_token, get_current_user, create_token
 from aiod.configuration import config
+from aiod import taxonomies
+from aiod import bookmarks
 from aiod.resources import case_studies
 from aiod.resources import computational_assets
 from aiod.resources import contacts
-from aiod.default.counts import asset_counts as counts
 from aiod.resources import datasets
 from aiod.resources import educational_resources
 from aiod.resources import events
@@ -17,5 +17,8 @@ from aiod.resources import projects
 from aiod.resources import publications
 from aiod.resources import services
 from aiod.resources import teams
-from aiod import taxonomies
+
+from aiod.authentication import invalidate_token, get_current_user, create_token
+from aiod.default.counts import asset_counts as counts
+from aiod.calls.calls import get_any_asset as get
 from aiod.__version__ import version
