@@ -2,6 +2,7 @@ import pandas as pd
 import requests
 from typing import Literal
 
+from aiod.configuration import config
 from aiod.calls.urls import server_url
 
 
@@ -14,18 +15,21 @@ def asset_counts(
 
     Parameters
     ----------
-        version (str | None): The version of the counts endpoint (default is None).
-        format (Literal["pandas", "json"]): The desired format for the response (default is "pandas").
-            For "json" format, the returned type is a json decoded type, in this case a dict.
+    version:
+        The version of the counts endpoint (default is None).
+    data_format:
+        The desired format for the response (default is "pandas").
+        For "json" format, the returned type is a json decoded type, in this case a dict.
 
     Returns
     -------
-        pd.DataFrame | dict: Counts as a Pandas data frame or a dictionary.
+    pd.DataFrame | dict
+        Counts as a Pandas data frame or a dictionary.
     """
     base_url = server_url(version)
     url = f"{base_url}counts"
 
-    res = requests.get(url)
+    res = requests.get(url, timeout=config.request_timeout_seconds)
 
     if data_format == "pandas":
         return pd.DataFrame(res.json())
